
#include <fstream>
#include <iostream>
#include <sstream>
#include <algorithm>
#include <iomanip>
#include <string>
#include <sys/stat.h>
#include <math.h>

#include "mpi.h"
#include "lammps.h"
#include "input.h"
#include "library.h"
#include "atom.h"

#include "sys/types.h"
#include "sys/sysinfo.h"

int main (int argc, char **argv){

  using namespace LAMMPS_NS;

  struct sysinfo memInfo;

  MPI_Init(&argc,&argv);

  int me;
  MPI_Comm_rank(MPI_COMM_WORLD, &me);

  LAMMPS *lmp = NULL;

  int niter = std::stoi(argv[1]);
  for (int i=0; i<niter; i++){

      if (me == 0) std::cout << "------ TIMESTEP: " << i+1 << " ------" << std::endl;

      // Creating LAMMPS instance
      lmp = new LAMMPS(1,NULL,MPI_COMM_WORLD);

      char cfile[1024];
      sprintf(cfile, "./in.set.lammps");
      lammps_file(lmp,cfile);

      delete lmp;

      sysinfo (&memInfo);
  		long long totalVirtualMem = memInfo.totalram;
  		//Add other values in next statement to avoid int overflow on right hand side...
  		totalVirtualMem += memInfo.totalswap;
  		totalVirtualMem *= memInfo.mem_unit;

  		long long virtualMemUsed = memInfo.totalram - memInfo.freeram;
  		//Add other values in next statement to avoid int overflow on right hand side...
  		virtualMemUsed += memInfo.totalswap - memInfo.freeswap;
  		virtualMemUsed *= memInfo.mem_unit;

  		if (me == 0) std::cout << " total virtual memory: " << totalVirtualMem << " - used virtual memory: " << virtualMemUsed << std::endl;

  }

  MPI_Finalize();

  return 0;
}
